==> synctera_client-0.32.0.dev2.tar.gz: synctera_client-0.32.0.dev2/synctera_client/apis/tags/__init__.py <==
# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from synctera_client.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    ACCOUNT_PRODUCTS = "Account Products"
    ACCOUNTS = "Accounts"
    ACCOUNT_TEMPLATES = "Account Templates"
    ACH = "ACH"
    ACH_TRANSACTION_SIMULATIONS = "ACH Transaction Simulations"
    BAN_RULES = "Ban Rules"
    BUSINESSES = "Businesses"
    CARDS = "Cards"
    EXTERNAL_CARDS_ALPHA = "External Cards (alpha)"
    CASH_PICKUPS_ALPHA = "Cash Pickups (alpha)"
    CUSTOMERS = "Customers"
    DISCLOSURES = "Disclosures"
    DISCLOSURES_DEPRECATED = "Disclosures (deprecated)"
    DOCUMENTS = "Documents"
    EXTERNAL_ACCOUNTS = "External Accounts"
    INTERNAL_ACCOUNTS = "Internal Accounts"
    KYC_VERIFICATION_DEPRECATED = "KYC Verification (deprecated)"
    MONITORING = "Monitoring"
    NOTES = "Notes"
    CRONUT = "Cronut"
    PERSONS = "Persons"
    REMOTE_CHECK_DEPOSIT = "Remote Check Deposit"
    RECONCILIATIONS = "Reconciliations"
    RELATIONSHIPS = "Relationships"
    SPEND_CONTROLS_BETA = "Spend Controls (beta)"
    STATELY = "Stately"
    CARD_TRANSACTION_SIMULATIONS = "Card Transaction Simulations"
    TRANSACTIONS = "Transactions"
    KYC_KYB_VERIFICATIONS = "KYC/KYB Verifications"
    WAITLIST = "Waitlist"
    WATCHLIST_DEPRECATED = "Watchlist (deprecated)"
    CARD_WEBHOOK_SIMULATIONS = "Card Webhook Simulations"
    WEBHOOKS = "Webhooks"
    WIRES_ALPHA = "Wires (alpha)"
    DIGITAL_WALLET_TOKENS = "Digital Wallet Tokens"
    INTERNAL_TRANSFER = "Internal Transfer"
    PAYMENT_SCHEDULES = "PaymentSchedules"
    REMOTE_CHECK_DEPOSIT_BETA = "Remote Check Deposit (beta)"
    SANDBOX_WIPE_ALPHA = "Sandbox Wipe (alpha)"
    STATEMENTS = "Statements"

==> synctera_client-0.35.0.tar.gz: synctera_client-0.35.0/synctera_client/apis/tags/__init__.py <==
# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from synctera_client.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    ACCOUNT_PRODUCTS = "Account Products"
    ACCOUNTS = "Accounts"
    ACCOUNT_TEMPLATES = "Account Templates"
    ACH = "ACH"
    ACH_TRANSACTION_SIMULATIONS = "ACH Transaction Simulations"
    ADMIN = "Admin"
    API_KEYS = "API Keys"
    BAN_RULES = "Ban Rules"
    BANKS = "Banks"
    QUICKSTART = "Quickstart"
    BUSINESSES = "Businesses"
    CARDS = "Cards"
    EXTERNAL_CARDS = "External Cards"
    CASH_PICKUPS_ALPHA = "Cash Pickups (alpha)"
    COMPLIANCE_SEARCHES = "Compliance Searches"
    CUSTOMERS = "Customers"
    DISCLOSURES = "Disclosures"
    DISCLOSURES_DEPRECATED = "Disclosures (deprecated)"
    DOCUMENTS = "Documents"
    STATELY = "Stately"
    EXTERNAL_ACCOUNTS = "External Accounts"
    IDENTITY = "Identity"
    INTERNAL_ACCOUNTS = "Internal Accounts"
    KYC_VERIFICATION_DEPRECATED = "KYC Verification (deprecated)"
    MIDDESK = "Middesk"
    MONITORING = "Monitoring"
    NOTES = "Notes"
    PARTNERS = "Partners"
    PARTY_GROUPS = "Party Groups"
    CRONUT = "Cronut"
    PERSONS = "Persons"
    POSTING_DATES = "Posting Dates"
    REMOTE_CHECK_DEPOSIT = "Remote Check Deposit"
    RDC_CONFIG = "RDC Config"
    RECONCILIATIONS = "Reconciliations"
    RELATIONSHIPS = "Relationships"
    ROLES = "Roles"
    SPEND_CONTROLS_BETA = "Spend Controls (beta)"
    TENANT_CONFIGS = "Tenant Configs"
    CARD_TRANSACTION_SIMULATIONS = "Card Transaction Simulations"
    TRANSACTION_RISK = "Transaction risk"
    TRANSACTIONS = "Transactions"
    USERS = "Users"
    EGRESS_GATEWAY_VENDOR_SECRET_CRUD_API = "Egress Gateway Vendor Secret CRUD API"
    KYC_KYB_VERIFICATIONS = "KYC/KYB Verifications"
    WAITLIST = "Waitlist"
    WATCHLIST_DEPRECATED = "Watchlist (deprecated)"
    EGRESS_GATEWAY_WEBHOOK_SECRET_CRUD_API = "Egress Gateway Webhook Secret CRUD API"
    CARD_WEBHOOK_SIMULATIONS = "Card Webhook Simulations"
    WEBHOOKS = "Webhooks"
    WIRES_ALPHA = "Wires (alpha)"
    DIGITAL_WALLET_TOKENS = "Digital Wallet Tokens"
    INTERNAL_TRANSFER = "Internal Transfer"
    PAYMENT_SCHEDULES = "PaymentSchedules"
    REMOTE_CHECK_DEPOSIT_BETA = "Remote Check Deposit (beta)"
    SANDBOX_WIPE_ALPHA = "Sandbox Wipe (alpha)"
    STATEMENTS = "Statements"
